@@ -46,6 +46,15 @@ Example:
   iex> IO.puts("hello world")
   hello world
 
+  These requires to use +pass because the output from the interpreter
+  gets mixed with the string typed in.
+  *However* they never worked.
+  iex> num = IO.gets("num: ")         # byexample: +input +pass
+  num: [42]
+  iex> num
+  "42\n"
+
+
 """
 
 from __future__ import unicode_literals
@@ -282,7 +291,7 @@ class ElixirInterpreter(ExampleRunner, PexpectMixin):
     def cancel(self, example, options):
         # the following lines tries to ensure that we write '#iex:break'
         # at the begin of a new line so IEx will interpret it
-        # unfortunatelly this also means that we will get spurious prompts
+        # unfortunately this also means that we will get spurious prompts
         # and ':nil' results.
         self._sendline("")
         self._sendline("")
